@@ -594,6 +594,12 @@ class EdgeFunction(
 
         return typing.cast(aws_cdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricThrottles", [props]))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="architecture")
+    def architecture(self) -> aws_cdk.aws_lambda.Architecture:
+        '''The system architectures compatible with this lambda function.'''
+        return typing.cast(aws_cdk.aws_lambda.Architecture, jsii.get(self, "architecture"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="connections")
     def connections(self) -> aws_cdk.aws_ec2.Connections:
